;; Generated package description from url-http-ntlm.el  -*- no-byte-compile: t -*-
(define-package "url-http-ntlm" "2.0.6" "NTLM authentication for the url library" '((emacs "24.4") (ntlm "2.1.0")) :commit "234228e02682b9000015f5aa668875ea5d4fe6f0" :authors '(("Tom Schutzer-Weissmann" . "tom.weissmann@gmail.com")) :maintainer '("Thomas Fitzsimmons" . "fitzsim@fitzsim.org") :keywords '("comm" "data" "processes" "hypermedia") :url "https://code.google.com/p/url-http-ntlm/")
